---
title: <span class="badge object-type-scalar"></span> Joule
---
# <span class="badge object-type-scalar"></span> Joule

Energy: Joule (J)

## Definition

```python
# Energy: Joule (J)
Joule: typing.Literal["joule"] = "joule"
```
